@@ -115,7 +115,8 @@ class NERExplainaboardBuilder:
         span_dic = {}
         for chunk in chunks:
             tag, sid, eid = chunk
-            span_text = ' '.join(sentence[sid:eid]).lower()
+            #span_text = ' '.join(sentence[sid:eid]).lower()
+            span_text = ' '.join(sentence[sid:eid])
             span_len = eid - sid
             span_pos = (sid, eid)
             span_dic = {'span_text': span_text, 'span_len': span_len, 'span_pos': span_pos, 'span_tag': tag}
@@ -321,7 +322,7 @@ class NERExplainaboardBuilder:
         dict_pos2tag_pred = {}
         for k_bucket_eval, spans_pred in self._samples_over_bucket_pred[feature_name].items():
             for span_pred in spans_pred:
-                pos_pred = "|||".join(span_pred.split("|||")[0:3])
+                pos_pred = "|||".join(span_pred.split("|||")[0:4])
                 tag_pred = span_pred.split("|||")[-1]
                 dict_pos2tag_pred[pos_pred] = tag_pred
         # print(dict_pos2tag_pred)
@@ -330,7 +331,7 @@ class NERExplainaboardBuilder:
         dict_pos2tag = {}
         for k_bucket_eval, spans in self._samples_over_bucket_true[feature_name].items():
             for span in spans:
-                pos = "|||".join(span.split("|||")[0:3])
+                pos = "|||".join(span.split("|||")[0:4])
                 tag = span.split("|||")[-1]
                 dict_pos2tag[pos] = tag
 
@@ -340,6 +341,8 @@ class NERExplainaboardBuilder:
             true_label = tag
             pred_label = ""
             sent_id = int(pos.split("|||")[0])
+            span = pos.split("|||")[-1]
+
 
             span_sentence = " ".join(self._data[sent_id]["tokens"])
 
@@ -349,7 +352,13 @@ class NERExplainaboardBuilder:
                     continue
             else:
                 pred_label = "O"
-            error_case = span_sentence + "|||" + true_label + "|||" + pred_label
+            #error_case = span+ "|||" + span_sentence + "|||" + true_label + "|||" + pred_label
+            error_case = {
+                "span":span,
+                "text":span_sentence,
+                "true_label":true_label,
+                "predicted_label":pred_label,
+            }
             errorCase_list.append(error_case)
 
         for pos, tag in dict_pos2tag_pred.items():
@@ -358,8 +367,8 @@ class NERExplainaboardBuilder:
             pred_label = tag
 
             sent_id = int(pos.split("|||")[0])
-
-            span_sentence = "".join(self._data[sent_id]["tokens"])
+            span = pos.split("|||")[-1]
+            span_sentence = " ".join(self._data[sent_id]["tokens"])
 
             if pos in dict_pos2tag.keys():
                 true_label = dict_pos2tag[pos]
@@ -367,7 +376,13 @@ class NERExplainaboardBuilder:
                     continue
             else:
                 true_label = "O"
-            error_case = span_sentence + "|||" + true_label + "|||" + pred_label
+            #error_case = span + "|||" + span_sentence + "|||" + true_label + "|||" + pred_label
+            error_case = {
+                "span":span,
+                "text":span_sentence,
+                "true_label":true_label,
+                "predicted_label":pred_label,
+            }
             errorCase_list.append(error_case)
 
         return errorCase_list
