@@ -182,9 +182,10 @@ class TCExplainaboardBuilder:
                 if self._info.results.is_print_case:
                     if true_label != predicted_label:
                         #bucket_case = true_label + "|||" + predicted_label + "|||" + sent
-                        bucket_case = {"true_label":(s_id,["true_label"]),
-                                       "predicted_label":(s_id,["predicted_label"]),
-                                       "text":(s_id,["text"])}
+                        # bucket_case = {"true_label":(s_id,["true_label"]),
+                        #                "predicted_label":(s_id,["predicted_label"]),
+                        #                "text":(s_id,["text"])}
+                        bucket_case = str(s_id)
                         bucket_cases.append(bucket_case)
 
             bucket_name_to_performance[bucket_interval] = []
