@@ -1,9 +1,8 @@
 import unittest
-import explainaboard
 from explainaboard.table_schema import table_schemas
-from explainaboard.constants import TaskType
+from explainaboard.tasks import TaskType
 
-class MyTestCase(unittest.TestCase):
+class TestTableSchema(unittest.TestCase):
     def test_table_schemas(self):
 
 
