@@ -23,7 +23,7 @@ class TestTextClassification(unittest.TestCase):
         metadata = {"task_name": TaskType.text_classification.value,
             "metric_names": ["Accuracy", "F1score"]}
 
-        processor = get_processor(TaskType.text_classification, metadata, self._system_output_data)
+        processor = get_processor(TaskType.text_classification.value, metadata, self._system_output_data)
         self.assertEqual(len(processor._features), 6)
 
         analysis = processor.process()
